@@ -31,9 +31,9 @@ BEGIN_NAMESPACE( classad )
     _classad_except
 
 extern int _except_line_number;
-extern char *_except_file_name;
-void _classad_except(char *format, ...);
+extern const char *_except_file_name;
+void _classad_except(const char *format, ...);
 
 END_NAMESPACE
 
-#endif /* __CLASSAD_DEBUG_H */
+#endif /* __CLASSAD_DEBUG_H__ */
