@@ -251,13 +251,15 @@ SameAs(const ExprTree *tree) const
             ArgumentList::const_iterator a1 = arguments.begin();
             ArgumentList::const_iterator a2 = other_fn->arguments.begin();
             while (a1 != arguments.end()) {
-                if (a2 == arguments.end()) {
+                if (a2 == other_fn->arguments.end()) {
                     is_same = false;
                     break;
                 } else if (!(*a1)->SameAs((*a2))) {
                     is_same = false;
                     break;
                 }
+				a1++;
+				a2++;
             }
         } else {
             is_same = false;
@@ -2241,13 +2243,20 @@ eval( const char* /* name */,const ArgumentList &argList,EvalState &state,
 	ClassAdParser parser;
 	ExprTree *expr = NULL;
 	if( !parser.ParseExpression( s.c_str(), expr, true ) || !expr ) {
+		if( expr ) {
+			delete expr;
+		}
 		result.SetErrorValue();
 		return true;
 	}
 
 	expr->SetParentScope( state.curAd );
 
-	if( !expr->Evaluate( result ) ) {
+	bool eval_ok = expr->Evaluate( result );
+
+	delete expr;
+
+	if( !eval_ok ) {
 		result.SetErrorValue();
 		return false;
 	}
